//@line 3 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 5 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 7 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 9 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 11 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 13 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 15 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 17 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 19 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 21 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 23 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 25 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 27 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 29 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 31 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 33 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 35 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 37 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 39 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 41 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 43 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 45 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 47 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 49 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 51 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 53 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 55 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 57 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 59 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 61 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 63 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 65 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 67 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 69 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"



//@line 73 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"



//@line 77 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

//@line 79 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

pref("calendar.week.start", 1);



//@line 85 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

pref("calendar.week.d0sundaysoff", true);

pref("calendar.week.d1mondaysoff", false);

pref("calendar.week.d2tuesdaysoff", false);

pref("calendar.week.d3wednesdaysoff", false);

pref("calendar.week.d4thursdaysoff", false);

pref("calendar.week.d5fridaysoff", false);

pref("calendar.week.d6saturdaysoff", true);



pref("general.useragent.locale", "da");



//@line 107 "/builds/tinderbox/Sb-Trunk-l10n/Linux_2.4.21-32.0.1.EL_Clobber/mozilla/calendar/locales/../../../l10n/da/calendar/sunbird-l10n.js"

pref("calendar.categories.names", "Jubilæum,Fødselsdag,Forretning,Opkald,Klienter,Konkurrenter,Kunder,Favoritter,Opfølgning,Gaver,Helligdage,Ideer,Problemer,Diverse,Personligt,Projekter,Offentlig helligdag,Status,Leverandører,Rejser,Ferie,Familie");

